library xmp_mmkeys;

uses
  Windows,
  xmpdsp in 'xmpdsp.pas',
  xmpfunc in 'xmpfunc.pas',
  global_hotkeys in 'global_hotkeys.pas';

const
  A_Ver = '0.2';
  XM_MSG = 1050;
  VK_MEDIA_STOP = $B2;
  VK_MEDIA_NEXT_TRACK = $B0;
  VK_MEDIA_PREV_TRACK = $B1;
  VK_MEDIA_PLAY_PAUSE = $B3;
  Plugin_Name = 'MultiMedia Keys Control';
  Global_HotKeys_Arr : array[0..3] of Byte =
    (
    VK_MEDIA_STOP,
    VK_MEDIA_NEXT_TRACK,
    VK_MEDIA_PREV_TRACK,
    VK_MEDIA_PLAY_PAUSE
    );

var
  XMPlayWinH : HWND;
  PluginDef : TXMPDSP;
  XmpFMisc : ^XMPFUNC_MISC;

procedure GlobalHotKeysProc(KeyId : integer);
begin
  case KeyId of
    VK_MEDIA_STOP :
      begin
        SendMessage(XMPlayWinH, XM_MSG, 81, 0);
      end;
    VK_MEDIA_PLAY_PAUSE :
      begin
        SendMessage(XMPlayWinH, XM_MSG, 80, 0);
      end;
    VK_MEDIA_PREV_TRACK :
      begin
        SendMessage(XMPlayWinH, XM_MSG, 129, 0);
      end;
    VK_MEDIA_NEXT_TRACK :
      begin
        SendMessage(XMPlayWinH, XM_MSG, 128, 0);
      end;
  end;
end;

procedure SetHotKeys;
var
  I : integer;
begin
  for I := Low(Global_HotKeys_Arr) to High(Global_HotKeys_Arr) do
  begin
    RegisterGlobalHotKey(Global_HotKeys_Arr[I], 0, Global_HotKeys_Arr[I], GlobalHotKeysProc);
  end;
end;

procedure UnSetHotKeys;
var
  I : integer;
begin
  for I := Low(Global_HotKeys_Arr) to High(Global_HotKeys_Arr) do
  begin
    UnregisterGlobalHotkey(Global_HotKeys_Arr[I]);
  end;
end;

procedure DSP_About(Win : HWND); stdcall;
begin
  MessageBox(Win, 'This plugin allow you to control XMPlay by MultiMedia ' +
    'Keys on your keyboard. Keys are: Play/Pause, Previous, Next and Stop. ' +
    'Written by: olesio (e-mail: oles@o2.pl). New version was rewritten to ' +
    'do not use global hook on keyboard, which may sometimes not work on a ' +
    'systems with UAC enabled and no admin rights.',
    PChar(Plugin_Name + ' ' + A_Ver), MB_ICONINFORMATION + MB_OK);
end;

function DSP_New : Pointer; stdcall;
begin
  XMPlayWinH := XmpFMisc.GetWindow;
  SetHotKeys;
  Result := Pointer(1);
end;

procedure DSP_Free(Inst : Pointer); stdcall;
begin
  UnSetHotKeys;
end;

function DSP_GetDescription(Inst : Pointer) : PAnsiChar; stdcall;
begin
  Result := PluginDef.Name;
end;

function DSP_GetConfig(Inst : Pointer; Config : Pointer) : DWORD; stdcall;
begin
  Result := 0;
end;

function DSP_SetConfig(Inst : Pointer; Config : Pointer; Size : DWORD) : LongBool; stdcall;
begin
  Result := True;
end;

function DSP_Process(Inst : Pointer; Data : PSingle; Count : DWORD) : DWORD; stdcall;
begin
  Result := Count;
end;

function XMPDSP_GetInterface2(Face : DWORD; Faceproc : TInterfaceProc) : Pointer; stdcall;
begin
  with PluginDef do
  begin
    Flags := 0;
    New := DSP_New;
    Free := DSP_Free;
    About := DSP_About;
    Name := Plugin_Name;
    Process := DSP_Process;
    GetConfig := DSP_GetConfig;
    SetConfig := DSP_SetConfig;
    GetDescription := DSP_GetDescription;
  end;
  XmpFMisc := @XMPFUNC_MISC(FaceProc(XMPFUNC_MISC_FACE)^);
  Result := @TXMPDSP(PluginDef);
end;

exports
  XMPDSP_GetInterface2;

begin
end.